@@ -1,5 +1,5 @@
 # file MASS/lm.gls.q
-# copyright (C) 1994-9 W. N. Venables and B. D. Ripley
+# copyright (C) 1994-2005 W. N. Venables and B. D. Ripley
 #
 lm.gls <-
     function(formula, data, W, subset, na.action, inverse = FALSE,
@@ -22,14 +22,18 @@ lm.gls <-
     d <- eW$values
     if(any(d <= 0)) stop("'W' is not positive definite")
     A <- diag(d^ifelse(inverse, -0.5, 0.5)) %*% t(eW$vector)
+    Ainv <- eW$vector %*% diag(d^ifelse(inverse, 0.5, -0.5))
     fit <- lm.fit(A %*% X, A %*% Y, method=method, ...)
+    ## revert to original coords
+    fit$fitted.values <- drop(Ainv %*% fit$fitted.values)
+    fit$residuals <- drop(Ainv %*% fit$residuals)
     fit$terms <- Terms
     fit$call <- call
     if(model) fit$model <- m
     if(x) fit$x <- X
     if(y) fit$y <- Y
     fit$na.action <- attr(m, "na.action")
-    class(fit) <- c("lm.gls", class(fit))
+    class(fit) <- "lm.gls"
     fit$xlevels <- .getXlevels(Terms, m)
     fit$contrasts <- attr(X, "contrasts")
     fit
